"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentservicetoken import PaymentServiceToken, PaymentServiceTokenTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CollectionNoCursorPaymentServiceTokenTypedDict(TypedDict):
    items: List[PaymentServiceTokenTypedDict]
    r"""A list of items returned for this request."""


class CollectionNoCursorPaymentServiceToken(BaseModel):
    items: List[PaymentServiceToken]
    r"""A list of items returned for this request."""
