"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


Method = Union[
    Literal[
        "abitab",
        "affirm",
        "afterpay",
        "alipay",
        "alipayhk",
        "applepay",
        "arcuspaynetwork",
        "bacs",
        "bancontact",
        "banked",
        "bcp",
        "becs",
        "bitpay",
        "boleto",
        "boost",
        "card",
        "cashapp",
        "chaseorbital",
        "clearpay",
        "click-to-pay",
        "dana",
        "dcb",
        "dlocal",
        "ebanx",
        "efecty",
        "eps",
        "everydaypay",
        "gcash",
        "gem",
        "gemds",
        "gift-card",
        "giropay",
        "givingblock",
        "gocardless",
        "googlepay",
        "googlepay_pan_only",
        "gopay",
        "grabpay",
        "ideal",
        "kakaopay",
        "kcp",
        "khipu",
        "klarna",
        "latitude",
        "latitudeds",
        "laybuy",
        "linepay",
        "linkaja",
        "maybankqrpay",
        "mercadopago",
        "multibanco",
        "multipago",
        "nequi",
        "netbanking",
        "network-token",
        "nupay",
        "oney_10x",
        "oney_12x",
        "oney_3x",
        "oney_4x",
        "oney_6x",
        "ovo",
        "oxxo",
        "pagoefectivo",
        "payid",
        "paymaya",
        "paypal",
        "paypalpaylater",
        "payto",
        "payvalida",
        "picpay",
        "pix",
        "pse",
        "rabbitlinepay",
        "razorpay",
        "rapipago",
        "redpagos",
        "scalapay",
        "sepa",
        "servipag",
        "shopeepay",
        "singteldash",
        "smartpay",
        "sofort",
        "spei",
        "stitch",
        "stripedd",
        "thaiqr",
        "touchngo",
        "truemoney",
        "trustly",
        "trustlyeurope",
        "upi",
        "venmo",
        "vipps",
        "waave",
        "webpay",
        "wechat",
        "yape",
        "zippay",
    ],
    UnrecognizedStr,
]
