"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


TransactionPaymentSource = Union[
    Literal["ecommerce", "moto", "recurring", "installment", "card_on_file"],
    UnrecognizedStr,
]
r"""The way payment method information made it to this transaction."""
